// src/loaders/devtools-loader.ts
import {
  isDev,
  debug as debug3,
  transformDevtoolsClient
} from "tailwindcss-webpack-plugin-utils";

// src/util.ts
import {
  BaseTailwindService,
  debug as debug2,
  ensureAbsolute
} from "tailwindcss-webpack-plugin-utils";

// src/devtools/server.ts
import { getPort } from "get-port-please";
import {
  promiseSingleton,
  debug,
  createDevtoolsMiddleware
} from "tailwindcss-webpack-plugin-utils";

// src/constants.ts
import { dirname, join } from "path";
import { fileURLToPath } from "url";
var PACKAGE_DIR = typeof __dirname !== "undefined" ? __dirname : dirname(fileURLToPath(import.meta.url));
var COMPILE_ENTRY_PATH = join(
  PACKAGE_DIR,
  "./templates/_compile-entry_.js"
);
var TAILWIND_ENTRY_PATH = join(
  PACKAGE_DIR,
  "./templates/_tailwind_.css"
);
var DEVTOOLS_ENTRY_PATH = join(
  PACKAGE_DIR,
  "./templates/_tailwind-devtools_.js"
);
var DEVTOOLS_LOADER_PATH = join(
  PACKAGE_DIR,
  "./loaders/devtools-loader.js"
);
var CSS_LOADER_PATH = join(PACKAGE_DIR, "./loaders/css-loader.js");

// src/util.ts
var isWebTarget = (target) => {
  let isWeb = true;
  const _isWebTarget = (checked) => !checked.includes("node") && !checked.includes("electron-preload") && !checked.includes("electron-main") && !checked.includes("nwjs");
  if (typeof target === "string") {
    isWeb = _isWebTarget(target);
  } else if (Array.isArray(target)) {
    target.forEach((checked) => {
      if (!_isWebTarget(checked)) {
        isWeb = false;
        return;
      }
    });
  }
  return isWeb;
};

// src/loaders/devtools-loader.ts
async function devtoolsLoader(source) {
  const callback = this.async();
  if (!this._compiler) {
    callback(null, source);
    return;
  }
  this.cacheable(false);
  if (isWebTarget(this._compiler.options.target) && isDev()) {
    const { port, host } = await this._compiler.$tailwind.server.ensureStart();
    const client = await transformDevtoolsClient(
      this._compiler.$tailwind.service,
      `http://${host}:${port}`
    );
    debug3(`[devtools-loader]: backend server started`);
    callback(null, client);
  } else {
    callback(null, "");
  }
}
export {
  devtoolsLoader as default
};
